@@ -93,10 +93,12 @@ class SourceCodeLoader(FileLoader):
 
 
 class AddonsLoader:
+    addons_path: Path
     files_repo: FilesResource = None
     store: DataStore = None
 
-    def __init__(self, files_repo: FilesResource, store: DataStore):
+    def __init__(self, addons_dir_path: Path, files_repo: FilesResource, store: DataStore):
+        self.addons_path = addons_dir_path
         self.files_repo = files_repo
         self.store = store
 
@@ -122,7 +124,7 @@ class AddonsLoader:
         raise NotImplementedError
 
     async def _discover_addon(self, filename: Path) -> ApiAddon | None:
-        async with (await self.files_repo.open(filename)) as file_:
+        async with (await self.files_repo.open(self.addons_path.joinpath(filename))) as file_:
             pl = ApiAddon(filename, await file_.read())
             pl = await self.configure_addon(pl)
             if pl.name is None:
@@ -136,8 +138,8 @@ class AddonsLoader:
             return pl
 
     async def discover_addons(self):
-        for filename in await self.files_repo.list(self.files_repo.root):
-            await self._discover_addon(filename)
+        for filepath in await self.files_repo.list(self.addons_path):
+            await self._discover_addon(filepath.name)
 
     async def delete_addon(self, filename: str):
         mdws = await self.store.get_item("addon")
