@@ -22,9 +22,11 @@ class MetricRequestEvent(IMessage):
     message_type = "metrics_request"
     destination = "__dispatcher__"
     exporter: MetricExporter
+    kind: str
 
-    def __init__(self, exporter: MetricExporter):
+    def __init__(self, exporter: MetricExporter, kind: str):
         super().__init__()
+        self.kind = kind
         self.exporter = exporter
 
 
