@@ -12,6 +12,7 @@ from sanic import Sanic, Request
 from sanic.response import BaseHTTPResponse
 
 from web_foundation.config import AppConf
+from web_foundation.extentions.addons.addon_loader import AddonsLoader
 from web_foundation.extentions.error_handler import ExtendedErrorHandler
 from web_foundation.extentions.metrics.events import NewMetricEvent
 from web_foundation.extentions.metrics.metric import HistogramMetric, CounterMetric, SummaryMetric, Metric
@@ -37,7 +38,7 @@ class App(Generic[GenericDependencyContainer]):
     _rt_listeners = list[tuple[list[Type[IMessage] | str], RtEventCallback, bool]]
 
     def __init__(self, dependency_container: GenericDependencyContainer,
-                 dispatcher: IDispatcher = None, with_addons=False):
+                 dispatcher: IDispatcher = None):
         self.name = dependency_container.app_config().app_name
         self.container = dependency_container
         self.sanic = Sanic(self.name, loads=orjson.loads, dumps=orjson.dumps,
@@ -123,6 +124,8 @@ class App(Generic[GenericDependencyContainer]):
                     callback=partial(s_app.ctx.rt_broadcaster.broadcast, resolve_callback=resolver),
                     use_nested_classes=use_nested_classes)
             await self.container.init_resources(s_app.ctx.channel)
+            if hasattr(self.container, "addon_loader") and self.container.addon_loader.initialized:
+                await self.container.addon_loader().first_init()
 
         async def reg_metrics(s_app: Sanic):
             async def give_metric(metric: Metric):
