@@ -13,6 +13,7 @@ from web_foundation.errors.app.application import InconsistencyError
 
 
 # ------------------------------------------------STR_TO---------------------------------------------------------------
+from web_foundation.kernel.dependency import Dependency
 
 
 def str_to_list(string: str) -> Union[List[str], None]:
@@ -106,6 +107,19 @@ def in_obj_subclasses(obj: object | Type, target_cls: Type):
         raise e
 
 
+def in_obj_subcls_of_dependencies(obj: object | Type, target_cls: Type):
+    try:
+        for i in dir(obj):
+            if not i.startswith("__"):
+                item = getattr(obj, i)
+                if isinstance(item, Dependency):
+                    item = item.initialized
+                if item.__class__ in all_subclasses(target_cls):
+                    yield item, i
+    except Exception as e:
+        raise e
+
+
 def in_obj_classes(obj: object | Type, target_cls: Type):
     try:
         for i in dir(obj):
